@@ -728,7 +728,7 @@ class Diar():
 
     def duration(self):
         """
-        :return: the sum of the segment duration
+        :return: t:qhe sum of the segment duration
         """
         l = 0
         for segment in self.segments:
@@ -849,10 +849,10 @@ class Diar():
                     loc = str2str_normalize(loc)
                 start = int(float(split[3])*100)
                 stop = int(float(split[4])*100)
-                addon = split[5].replace(">", "").replace("<", "").replace(","," ")
+                addon = split[5].replace(">", "").replace("<", "")
                 lineBis = re.sub('\s+',' ',addon)
                 lineBis = lineBis.strip()
-                gender = lineBis.split()[2]
+                gender = lineBis.split(",")[2]
                 if normalize_cluster:
                     word = str2str_normalize(word)
                 # print(show, tmp, start, length, gender, channel, env, speaker)
