@@ -20,9 +20,11 @@
 
 
 """
-Copyright 2014-2020 Anthony Larcher
+Copyright 2014-2021 Anthony Larcher
 """
 
 from .wavsets import SeqSet
+from .wavsets import create_train_val_seqtoseq
 from .seqtoseq import BLSTM
-from .seqtoseq import SeqToSeq
\ No newline at end of file
+from .seqtoseq import SeqToSeq
+from .seqtoseq import seqTrain
\ No newline at end of file
